# Generated by Django 4.1.1 on 2022-09-17 18:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("stagedoor", "0004_auto_20200507_2028"),
    ]

    operations = [
        migrations.AlterField(
            model_name="authtoken",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="email",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
        migrations.AlterField(
            model_name="phonenumber",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
    ]
