# Generated by Django 3.0.5 on 2020-04-08 04:17

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("stagedoor", "0002_auto_20200408_0415"),
    ]

    operations = [
        migrations.AlterField(
            model_name="authtoken",
            name="email",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="stagedoor.Email",
            ),
        ),
        migrations.AlterField(
            model_name="authtoken",
            name="phone_number",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="stagedoor.PhoneNumber",
            ),
        ),
    ]
