# Generated by Django 3.0.6 on 2020-05-07 20:28

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("stagedoor", "0003_auto_20200408_0417"),
    ]

    operations = [
        migrations.AddField(
            model_name="email",
            name="potential_user",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="stagedoor_potential_user_email",
                to=settings.AUTH_USER_MODEL,
            ),
        ),
        migrations.AddField(
            model_name="phonenumber",
            name="potential_user",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="stagedoor_potential_user_phone_number",
                to=settings.AUTH_USER_MODEL,
            ),
        ),
    ]
